==> ice-3.7.5.tgz: package/src/es5/Glacier2/Router.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

//
// Copyright (c) ZeroC, Inc. All rights reserved.
//
//
// Ice version 3.7.5
//
// <auto-generated>
//
// Generated from file `Router.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

/* eslint-disable */

/* jshint ignore: start */

/* slice2js browser-bundle-skip */
(function (module, require, exports) {
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
  var _ModuleRegistry = require("../Ice/ModuleRegistry").Ice._ModuleRegistry;

  var Glacier2 = _ModuleRegistry.require(module, ["../Glacier2/Session", "../Glacier2/PermissionsVerifier"]).Glacier2;

  var Ice = _ModuleRegistry.require(module, ["../Ice/Object", "../Ice/Value", "../Ice/ObjectPrx", "../Ice/Operation", "../Ice/Exception", "../Ice/Long", "../Ice/HashMap", "../Ice/HashUtil", "../Ice/ArrayUtil", "../Ice/StreamHelpers", "../Ice/Router"]).Ice;

  var Slice = Ice.Slice;
  /* slice2js browser-bundle-skip-end */

  /**
   * This exception is raised if a client tries to destroy a session
   * with a router, but no session exists for the client.
   *
   * @see Router#destroySession
   *
   **/

  Glacier2.SessionNotExistException = /*#__PURE__*/function (_Ice$UserException) {
    _inherits(_class, _Ice$UserException);

    var _super = _createSuper(_class);

    function _class() {
      var _cause = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      _classCallCheck(this, _class);

      return _super.call(this, _cause);
    }

    _createClass(_class, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Glacier2.SessionNotExistException;
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Glacier2::SessionNotExistException";
      }
    }]);

    return _class;
  }(Ice.UserException);

  var iceC_Glacier2_Router_ids = ["::Glacier2::Router", "::Ice::Object", "::Ice::Router"];
  /**
   * The Glacier2 specialization of the <code>Ice::Router</code> interface.
   *
   **/

  Glacier2.Router = /*#__PURE__*/function (_Ice$Object) {
    _inherits(_class2, _Ice$Object);

    var _super2 = _createSuper(_class2);

    function _class2() {
      _classCallCheck(this, _class2);

      return _super2.apply(this, arguments);
    }

    _createClass(_class2, null, [{
      key: "_iceImplements",
      get: function get() {
        return [Ice.Router];
      }
    }]);

    return _class2;
  }(Ice.Object);

  Glacier2.RouterPrx = /*#__PURE__*/function (_Ice$ObjectPrx) {
    _inherits(_class3, _Ice$ObjectPrx);

    var _super3 = _createSuper(_class3);

    function _class3() {
      _classCallCheck(this, _class3);

      return _super3.apply(this, arguments);
    }

    _createClass(_class3, null, [{
      key: "_implements",
      get: function get() {
        return [Ice.RouterPrx];
      }
    }]);

    return _class3;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Glacier2.Router, Glacier2.RouterPrx, iceC_Glacier2_Router_ids, 0, {
    "getCategoryForClient": [, 2, 1,, [7],,,,,],
    "createSession": [,,, 2, ["Glacier2.SessionPrx"], [[7], [7]],, [Glacier2.CannotCreateSessionException, Glacier2.PermissionDeniedException],,],
    "createSessionFromSecureConnection": [,,, 2, ["Glacier2.SessionPrx"],,, [Glacier2.CannotCreateSessionException, Glacier2.PermissionDeniedException],,],
    "refreshSession": [,,,,,,, [Glacier2.SessionNotExistException],,],
    "destroySession": [,,,,,,, [Glacier2.SessionNotExistException],,],
    "getSessionTimeout": [, 2, 1,, [4],,,,,],
    "getACMTimeout": [, 2, 1,, [3],,,,,]
  });
  /* slice2js browser-bundle-skip */

  exports.Glacier2 = Glacier2;
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
})(typeof global !== "undefined" && typeof global.process !== "undefined" ? module : undefined, typeof global !== "undefined" && typeof global.process !== "undefined" ? require : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self.Ice._require : window.Ice._require, typeof global !== "undefined" && typeof global.process !== "undefined" ? exports : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self : window);
/* slice2js browser-bundle-skip-end */

==> ice-3.7.70.tgz: package/src/es5/Glacier2/Router.js <==
"use strict";

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

//
// Copyright (c) ZeroC, Inc. All rights reserved.
//
//
// Ice version 3.7.7
//
// <auto-generated>
//
// Generated from file `Router.ice'
//
// Warning: do not edit this file.
//
// </auto-generated>
//

/* eslint-disable */

/* jshint ignore: start */

/* slice2js browser-bundle-skip */
(function (module, require, exports) {
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
  var _ModuleRegistry = require("../Ice/ModuleRegistry").Ice._ModuleRegistry;

  var Glacier2 = _ModuleRegistry.require(module, ["../Glacier2/Session", "../Glacier2/PermissionsVerifier"]).Glacier2;

  var Ice = _ModuleRegistry.require(module, ["../Ice/Object", "../Ice/Value", "../Ice/ObjectPrx", "../Ice/Operation", "../Ice/Exception", "../Ice/Long", "../Ice/HashMap", "../Ice/HashUtil", "../Ice/ArrayUtil", "../Ice/StreamHelpers", "../Ice/Router"]).Ice;

  var Slice = Ice.Slice;
  /* slice2js browser-bundle-skip-end */

  /**
   * This exception is raised if a client tries to destroy a session
   * with a router, but no session exists for the client.
   *
   * @see Router#destroySession
   *
   **/

  Glacier2.SessionNotExistException = /*#__PURE__*/function (_Ice$UserException) {
    _inherits(_class, _Ice$UserException);

    var _super = _createSuper(_class);

    function _class() {
      var _cause = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : "";

      _classCallCheck(this, _class);

      return _super.call(this, _cause);
    }

    _createClass(_class, [{
      key: "_mostDerivedType",
      value: function _mostDerivedType() {
        return Glacier2.SessionNotExistException;
      }
    }], [{
      key: "_parent",
      get: function get() {
        return Ice.UserException;
      }
    }, {
      key: "_id",
      get: function get() {
        return "::Glacier2::SessionNotExistException";
      }
    }]);

    return _class;
  }(Ice.UserException);

  var iceC_Glacier2_Router_ids = ["::Glacier2::Router", "::Ice::Object", "::Ice::Router"];
  /**
   * The Glacier2 specialization of the <code>Ice::Router</code> interface.
   *
   **/

  Glacier2.Router = /*#__PURE__*/function (_Ice$Object) {
    _inherits(_class2, _Ice$Object);

    var _super2 = _createSuper(_class2);

    function _class2() {
      _classCallCheck(this, _class2);

      return _super2.apply(this, arguments);
    }

    _createClass(_class2, null, [{
      key: "_iceImplements",
      get: function get() {
        return [Ice.Router];
      }
    }]);

    return _class2;
  }(Ice.Object);

  Glacier2.RouterPrx = /*#__PURE__*/function (_Ice$ObjectPrx) {
    _inherits(_class3, _Ice$ObjectPrx);

    var _super3 = _createSuper(_class3);

    function _class3() {
      _classCallCheck(this, _class3);

      return _super3.apply(this, arguments);
    }

    _createClass(_class3, null, [{
      key: "_implements",
      get: function get() {
        return [Ice.RouterPrx];
      }
    }]);

    return _class3;
  }(Ice.ObjectPrx);

  Slice.defineOperations(Glacier2.Router, Glacier2.RouterPrx, iceC_Glacier2_Router_ids, 0, {
    "getCategoryForClient": [, 2, 1,, [7],,,,,],
    "createSession": [,,, 2, ["Glacier2.SessionPrx"], [[7], [7]],, [Glacier2.CannotCreateSessionException, Glacier2.PermissionDeniedException],,],
    "createSessionFromSecureConnection": [,,, 2, ["Glacier2.SessionPrx"],,, [Glacier2.CannotCreateSessionException, Glacier2.PermissionDeniedException],,],
    "refreshSession": [,,,,,,, [Glacier2.SessionNotExistException],,],
    "destroySession": [,,,,,,, [Glacier2.SessionNotExistException],,],
    "getSessionTimeout": [, 2, 1,, [4],,,,,],
    "getACMTimeout": [, 2, 1,, [3],,,,,]
  });
  /* slice2js browser-bundle-skip */

  exports.Glacier2 = Glacier2;
  /* slice2js browser-bundle-skip-end */

  /* slice2js browser-bundle-skip */
})(typeof global !== "undefined" && typeof global.process !== "undefined" ? module : undefined, typeof global !== "undefined" && typeof global.process !== "undefined" ? require : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self.Ice._require : window.Ice._require, typeof global !== "undefined" && typeof global.process !== "undefined" ? exports : typeof WorkerGlobalScope !== "undefined" && self instanceof WorkerGlobalScope ? self : window);
/* slice2js browser-bundle-skip-end */
